@@ -69,11 +69,18 @@ def create_command(params):
 
     print(f"{config=}")
     if params.extra_vars:
+        types = {"int": int, "list": list, "str": str, "none": str, None: str}
         for i in params.extra_vars:
             path, value = i.split("=")
             path = path.split('/')
+            value = value.split(":")
+            if len(value) == 2:
+                type_value = value[1]
+            else:
+                type_value = None
+            value = value[0]
             element = __walk_on_json_path__("/".join(path[:-1]), config, config)
-            element[path[-1]] = value
+            element[path[-1]] = types[type_value](value)
 
     __dump_json__(params.config_file, config)
     print('Конфигурация создана')
